from setuptools import setup

setup(name='neuraldon',
      version='0.1.1',
      description='Python Package',
      packages = ['package'],
      install_requires = [],
      zip_safe = False,
      )